@@ -16,10 +16,9 @@ import re
 import os.path
 import mimetypes
 
+find_binary = re.compile(b'[\0-\7]').search
 
-find_binary = re.compile('[\0-\7]').search
 
-  
 def text_type(s):
     """Given an unnamed piece of text, try to guess its content type.
 
@@ -31,25 +30,25 @@ def text_type(s):
     s2 = s.strip()[:max_tags].lower()
 
     if len(s2) == max_tags:
-        if s2.startswith('<html>'):
+        if s2.startswith(b'<html>'):
             return 'text/html'
 
-        if s2.startswith('<!doctype html'):
+        if s2.startswith(b'<!doctype html'):
             return 'text/html'
 
         # what about encodings??
-        if s2.startswith('<?xml'):
+        if s2.startswith(b'<?xml'):
             return 'text/xml'
 
     # we also recognize small snippets of HTML - the closing tag might be
-    # anywhere, even at the end of 
-    if '</' in s:
+    # anywhere, even at the end of
+    if b'</' in s:
         return 'text/html'
 
     return 'text/plain'
- 
 
-def guess_content_type(name='', body='', default=None):
+
+def guess_content_type(name='', body=b'', default=None):
     """Given a named piece of content, try to guess its content type.
 
     The implementation relies on the 'mimetypes' standard Python module,
@@ -105,7 +104,15 @@ def add_files(filenames):
 here = os.path.dirname(os.path.abspath(__file__))
 add_files([os.path.join(here, "mime.types")])
 
-if __name__ == '__main__':
+# Python 2/3 compatibility for testing.
+def _print(s):
+    print(s)
+
+def main():
     items = mimetypes.types_map.items()
-    items.sort()
-    for item in items: print "%s:\t%s" % item
+    items = sorted(items)
+    for item in items:
+        _print("%s:\t%s" % item)
+
+if __name__ == '__main__': #pragma: nocover
+    main()
